<template>
  <BasicModal v-bind="$attrs" @register="register" :title="t('添加货架')" @ok="handleSubmit">
    <div class="pt-3px pr-3px">
      <BasicForm @register="registerForm" :model="model" />
    </div>
  </BasicModal>
</template>
<script lang="ts">
import { defineComponent, ref, nextTick, unref } from 'vue';
import { BasicModal, useModalInner } from '/@/components/Modal';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
import { SaveShelf } from '/@/api/tigerapi/wms/house';
import { useI18n } from '/@/hooks/web/useI18n';
import { useMessage } from '/@/hooks/web/useMessage';

const { t } = useI18n('WMS.WareHouse');
const { createMessage } = useMessage();
const schemas: FormSchema[] = [
  {
    field: 'SHELF_NAME',
    component: 'Input',
    label: t('货架名称'),
    defaultValue: '',
    colProps: {
      span: 24,
    },
    required: true,
  },
  {
    field: 'SHELF_CODE',
    component: 'Input',
    label: t('货架代码'),
    defaultValue: '',
    colProps: {
      span: 24,
    },
    required: true,
  },
  {
    field: 'field1',
    component: 'Input',
    label: 'region_code',
    colProps: {
      span: 24,
    },
    show: false,
  },
  {
    field: 'field2',
    component: 'Input',
    label: 'org_code',
    colProps: {
      span: 24,
    },
    show: false,
  },
];
export default defineComponent({
  components: { BasicModal, BasicForm },
  props: {
    userData: { type: Object },
  },
  emit: ['success', 'register'],
  setup(_, { emit }) {
    const modelRef = ref({});
    const [
      registerForm,
      {
        // setFieldsValue,
        // setProps
        validate,
      },
    ] = useForm({
      labelWidth: 120,
      schemas,
      showActionButtonGroup: false,
      actionColOptions: {
        span: 24,
      },
    });

    const [register, { setModalProps, closeModal }] = useModalInner((data) => {
      setModalProps({ confirmLoading: false });
      data && onDataReceive(data);
    });

    function onDataReceive(data) {
      console.log('Data Received', data);
      // 方式1;
      // setFieldsValue({
      //   field2: data.data,
      //   field1: data.info,
      // });

      // // 方式2
      modelRef.value = { field2: data.data, field1: data.info, SHELF_CODE: '', SHELF_NAME: '' };

      // setProps({
      //   model:{ field2: data.data, field1: data.info }
      // })
    }

    // function handleVisibleChange(v) {
    //   v && props.userData && nextTick(() => onDataReceive(props.userData));
    // }

    async function handleSubmit() {
      try {
        const values = await validate();
        setModalProps({ confirmLoading: true });
        // TODO custom api
        //保存用户
        const apiAction = SaveShelf(values, unref(false));
        apiAction.then((action) => {
          if (action) {
            if (action.IsSuccessed) {
                closeModal();
                createMessage.success(t('添加成功'));
                emit('success', {
                  isUpdate: unref(false),
                  values: { ...values, id: 0 },
                });
            }
          } else {
            createMessage.error(t('添加失败,代码已使用'));
          }
        });
      } finally {
        setModalProps({ confirmLoading: false });
      }
    }

    return { register, schemas, registerForm, model: modelRef, handleSubmit, t };
  },
});
</script>
